Cell class
Class intended to work as a wrapper for a value that is supposed to change.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue ↔ String?
-
getter/setter pair
- onEditingCompleteCallback ↔ void Function()?
-
Callback function that will be invoked once the edition of the cell is completed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textEditingController ↔ TextEditingController
-
getter/setter pair
- validator ↔ bool Function(String value)?
-
Function that defines whether a value is valid or not.
getter/setter pair
Methods
-
getValue(
) → String - Gets the current value of the cell.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
String value) → void - Sets a value for the cell.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited